Received: from malur.postgresql.org ([2a02:16a8:dc51::56]) by arkaria.postgresql.org with esmtps (TLS1.2:ECDHE_RSA_AES_256_CBC_SHA384:256) (Exim 4.89) (envelope-from ) id 1g2pcW-0003Sc-JD for pgsql-hackers@arkaria.postgresql.org; Thu, 20 Sep 2018 03:27:12 +0000 Received: from localhost ([127.0.0.1] helo=malur.postgresql.org) by malur.postgresql.org with esmtp (Exim 4.89) (envelope-from ) id 1g2pcS-00019o-TE for pgsql-hackers@arkaria.postgresql.org; Thu, 20 Sep 2018 03:27:08 +0000 Received: from makus.postgresql.org ([2001:4800:1501:1::229]) by malur.postgresql.org with esmtps (TLS1.2:ECDHE_RSA_AES_256_CBC_SHA384:256) (Exim 4.89) (envelope-from ) id 1g2pcS-00019h-Ig for pgsql-hackers@lists.postgresql.org; Thu, 20 Sep 2018 03:27:08 +0000 Received: from sss.pgh.pa.us ([66.207.139.130]) by makus.postgresql.org with esmtps (TLS1.2:ECDHE_RSA_AES_256_CBC_SHA384:256) (Exim 4.89) (envelope-from ) id 1g2pcL-00031F-C7; Thu, 20 Sep 2018 03:27:06 +0000 Received: from sss1.sss.pgh.pa.us (localhost [127.0.0.1]) by sss.pgh.pa.us (8.14.4/8.14.4) with ESMTP id w8K3Qq4E011292; Wed, 19 Sep 2018 23:26:52 -0400 From: Tom Lane To: Andres Freund cc: Amit Khandekar , Andreas Joseph Krogh , Robert Haas , Alvaro Herrera , "Jonathan S. Katz" , PostgreSQL Hackers Subject: Re: Query is over 2x slower with jit=on In-reply-to: <20180919224047.mcdjwis56ywqzhzs@alap3.anarazel.de> References: <20180822161241.je6nghzjsktbb57b@alap3.anarazel.de> <20180822165155.tjbib4pewnbiyy4x@alap3.anarazel.de> <20180910160909.qf3h3ttztvbyyuds@alap3.anarazel.de> <27812.1537221015@sss.pgh.pa.us> <20180919224047.mcdjwis56ywqzhzs@alap3.anarazel.de> Comments: In-reply-to Andres Freund message dated "Wed, 19 Sep 2018 15:40:47 -0700" MIME-Version: 1.0 Content-Type: text/plain; charset="us-ascii" Content-ID: <11290.1537414012.1@sss.pgh.pa.us> Content-Transfer-Encoding: quoted-printable Date: Wed, 19 Sep 2018 23:26:52 -0400 Message-ID: <11291.1537414012@sss.pgh.pa.us> List-Id: List-Help: List-Subscribe: List-Post: List-Owner: List-Archive: Precedence: bulk Andres Freund writes: > On 2018-09-17 17:50:15 -0400, Tom Lane wrote: >> Just to throw a contrarian opinion into this: I find the current EXPLAI= N >> output for JIT to be insanely verbose already. > Hm, it'd have been nice to get that feedback a little bit earlier, I did > inquire... > Currently: > JIT: > Functions: 2 > Generation Time: 0.680 ms > Inlining: true > Inlining Time: 7.591 ms > Optimization: true > Optimization Time: 20.522 ms > Emission Time: 14.607 ms Just to clarify, that seems perfectly fine for the "machine readable" output formats. I'd just like fewer lines in the "human readable" output. > How about making that: > JIT: > Functions: 2 > Options: Inlining, Optimization > Times (Total, Generation, Inlining, Optimization, Emission): 43.4 ms, = 0.680 ms, 7.591 ms, 20.522 ms, 14.607 ms > or something similar? That's going in the right direction. Personally I'd make the last line more like Times: generation 0.680 ms, inlining 7.591 ms, optimization 20.522 ms,= emission 14.607 ms, total 43.4 ms (total at the end seems more natural to me, YMMV). Also, the "options" format you suggest here seems a bit too biased towards binary on/off options --- what happens when there's a three-way option? So maybe that line should be like Options: inlining on, optimization on though I'm less sure about that part. regards, tom lane